//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Tile](../index.md)/[Companion](index.md)/[all](all.md)

# all

[common]\
val [all](all.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../index.md)&gt;

所有牌
